.reveal .slide-number {
    font-size: 26px;
    border-radius: 5px;
    background-color: rgba(0, 0, 0, .3);
}

.reveal .slides {
    border: 1.5px #ddd solid;
    border-radius: 7px;
    text-align: left;
    font-weight: 300;
}

.reveal h1,
.reveal h2,
.reveal h3,
.reveal h4 {
    font-family: 'Lato', 'SimHei', 'STXihei', 'Sans Serif';
    font-weight: 400;
}

.reveal p,
.reveal li,
.reveal center {
    font-size: 32px;
    font-family: 'Lato', 'STHeiti', 'SimHei', 'Sans Serif';
}

.reveal li+li {
    margin-top: 10px;
}

.reveal ul {
    display: block;
    margin-right: 15px;
}

.reveal p,
.reveal h1,
.reveal h2,
.reveal h3,
.reveal h4,
.reveal h5 {
    padding: 0 25px 0 25px;
}

.reveal table {
    font-size: 32px;
    font-family: 'Lato', 'STHeiti', 'SimHei', 'Sans Serif';
    margin-top: 15px;
    margin-bottom: 15px;
}

.reveal th {
    background-color: #eee;
}

.reveal tr:nth-child(even) {
    background-color: #efffff;
}

.reveal h1,
.reveal h2,
.reveal h3,
.reveal h4,
.reveal h5,
.reveal h6 {
    text-align: left;
    margin: 0 0 20px 0;
    color: #222;
    font-weight: 400;
    line-height: 1.2;
    letter-spacing: normal;
}

.reveal h1 {
    margin: 0 10 0 10;
    font-size: 60px;
}

.reveal .middle h1 {
    text-align: center;
}

.reveal h2 {
    font-size: 48px;
    border-bottom: 2px solid rgb(106, 0, 95);
    padding-bottom: 5px;
}

.reveal h3 {
    font-size: 1.15em;
}

.reveal h4 {
    font-size: 1.05em;
}

.reveal .center {
    text-align: center;
}

.reveal .middle {
    height: 728px;
    display: flex;
    align-items: center;
    width: 100%;
}

.reveal pre {
    font-size: 28px;

    background-color: #eee;

    border-radius: 3mm;
    padding: 10px 10px 10px 10px;
}

.reveal pre code {
    max-height: none;
}

.reveal code {
    font-family: 'Inconsolata', 'STKaiti', 'KaiTi', 'Sans Serif', Monospace;
}

.reveal .middle blockquote {
    text-align: center;
    color: rgb(106, 0, 95);
    background: none;
    box-shadow: none;
}

.reveal .middle blockquote a {
    color: inherit;
}

.reveal blockquote p,
.reveal blockquote li {
    font-family: 'Lato', 'STKaiti', 'KaiTi', 'Sans Serif';
}

section .center {
    display: block;
    margin-left: auto;
    margin-right: auto;
}

.reveal .author-block {
    margin: 75px 0 35px 0;
}

.reveal .author-affiliation img {
    margin: 15px 0 0 0;
}

.reveal .author-block p,
.reveal .author-affiliation p {
    font-family: 'Kaiti', 'STKaiti', 'Serif', 'Times', 'Times New Roman';
    margin-block-start: 0em;
    margin-block-end: 0em;
}

.reveal .author-affiliation {
    display: inline-block;
    font-size: 90%;
}

.reveal hr {
    border: 10px solid rgba(0, 0, 0, 0);
}

.reveal li {
    margin-top: 10px;
}

.reveal .mul-cols {
    display: flex;
}
.reveal .mul-cols .col {
    width: 100%
}
